@@ -1,5 +1,3 @@
-from torchyolo.utils.config_utils import get_config
-
 MODEL_TYPE_TO_MODEL_CLASS_NAME = {
     "yolov5": "Yolov5DetectionModel",
     "yolov7": "Yolov7DetectionModel",
@@ -10,10 +8,9 @@ MODEL_TYPE_TO_MODEL_CLASS_NAME = {
 class AutoDetectionModel:
     def from_pretrained(
         config_path: str,
+        model_type: str = "yolov5",
     ):
 
-        config = get_config(config_path)
-        model_type = config.DETECTOR_CONFIG.DETECTOR_TYPE
         model_class_name = MODEL_TYPE_TO_MODEL_CLASS_NAME[model_type]
         DetectionModel = getattr(
             __import__(f"torchyolo.modelhub.{model_type}", fromlist=[model_class_name]), model_class_name
