@@ -2,7 +2,7 @@ import cv2
 import torch
 from tqdm import tqdm
 
-from torchyolo.tracker_zoo import load_tracker
+from torchyolo.tracker.tracker_zoo import load_tracker
 from torchyolo.utils.config_utils import get_config
 from torchyolo.utils.dataset import LoadData, create_video_writer
 from torchyolo.utils.object_vis import video_vis
@@ -16,10 +16,7 @@ class Yolov8DetectionModel:
     def load_config(self, config_path: str):
         self.config_path = config_path
         config = get_config(config_path)
-        self.input_path = config.DATA_CONFIG.INPUT_PATH
         self.output_path = config.DATA_CONFIG.OUTPUT_PATH
-        self.model_type = config.DETECTOR_CONFIG.DETECTOR_TYPE
-        self.model_path = config.DETECTOR_CONFIG.MODEL_PATH
         self.device = config.DETECTOR_CONFIG.DEVICE
         self.conf = config.DETECTOR_CONFIG.CONF_TH
         self.iou = config.DETECTOR_CONFIG.IOU_TH
@@ -27,11 +24,11 @@ class Yolov8DetectionModel:
         self.save = config.DATA_CONFIG.SAVE
         self.show = config.DATA_CONFIG.SHOW
 
-    def load_model(self):
+    def load_model(self, model_path: str = "yolov8s.pt"):
         try:
             from ultralytics import YOLO
 
-            model = YOLO(self.model_path)
+            model = YOLO(model_path)
             model.conf = self.conf
             model.iou = self.iou
             self.model = model
@@ -39,18 +36,35 @@ class Yolov8DetectionModel:
         except ImportError:
             raise ImportError('Please run "pip install ultralytics" ' "to install YOLOv8 first for YOLOv8 inference.")
 
-    def predict(self, tracker=True):
-        tracker_module = load_tracker(self.config_path)
-        config = get_config(self.config_path)
-        input_path = config.DATA_CONFIG.INPUT_PATH
+    def predict(
+        self,
+        source: str = None,
+        tracker_type: str = None,
+        tracker_weight_path: str = None,
+        tracker_config_path: str = None,
+    ):
+        if tracker_type == "STRONGSORT":
+            tracker_module = load_tracker(
+                config_path=self.config_path,
+                tracker_type=tracker_type,
+                tracker_weight_path=tracker_weight_path,
+                tracker_config_path=tracker_config_path,
+            )
+
+        else:
+            tracker_module = load_tracker(
+                config_path=self.config_path,
+                tracker_type=tracker_type,
+                tracker_config_path=tracker_config_path,
+            )
 
         tracker_outputs = [None]
-        dataset = LoadData(input_path)
-        video_writer = create_video_writer(video_path=input_path, output_path="output")
+        dataset = LoadData(source)
+        video_writer = create_video_writer(video_path=source, output_path=self.output_path)
 
         for img_src, img_path, vid_cap in tqdm(dataset):
             results = self.model.predict(img_src, imgsz=self.image_size)
-            if tracker:
+            if tracker_type is not None:
                 for image_id, prediction in enumerate(results):
                     boxes = prediction[:].boxes.xyxy
                     score = prediction[:].boxes.conf
